/***** interface.c ************************************************
 * Description: Routine for gathering arguments from the command
 *              line.
 * Author: Bernhard Haubold, bernhard.haubold@fh-weihenstephan.de
 * File created on Sun Jun 20 13:12:10 2004.
 *****************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include "interface.h"

Args getArgs(int argc, char *argv[]){
  Args args;
  char c;
  int i, arg;

  args.h = 0;
  args.e = 0;
  args.a = 0;
  args.t = -1;
  args.n = -1;
  arg = 1;
  while(arg < argc){
    if(argv[arg][0] == '-'){
      c = argv[arg][1];
      switch(c){
	case 'n' :                            /* length of output lines */
	  args.n = (int)atoi(argv[++arg]);
	  break;
	case 't':
	  args.t = atof(argv[++arg]);
	  break;
	case 'h':                            /* print help */
	  args.h = 1;
	  break;
	case 'a':                            /* use approximation */
	  args.a = 1;
	  break;
	default:
	  printf("# unknown argument: %c\n",c);
	  args.e = 1;
	  return args;
      }
      arg++;
    }
  }
  if(args.t == -1 || args.n == -1){
    args.e = 1;
  }
  return args;
}

void printUsage(char *version){
  printf("watterson version %s, copyright (c) 2006, Bernhard Haubold\n", version);
  printf("purpose: compute expected number of segregating sites, S, using Watterson's equation\n");
  printf("arguments:  \n");
  printf("\t -n sample size\n");
  printf("\t -t theta\n");
  printf("\t [-a use approximation S = t * (ln n + g); default: use exact formula]\n");
  printf("\t [-h print this help message; default: do not print help]\n");
}
